summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/scripting/kexidb/kexidbfield.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/plugins/scripting/kexidb/kexidbfield.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/plugins/scripting/kexidb/kexidbfield.h')
-rw-r--r--kexi/plugins/scripting/kexidb/kexidbfield.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kexi/plugins/scripting/kexidb/kexidbfield.h b/kexi/plugins/scripting/kexidb/kexidbfield.h
index a4c2ef23..4cc85f38 100644
--- a/kexi/plugins/scripting/kexidb/kexidbfield.h
+++ b/kexi/plugins/scripting/kexidb/kexidbfield.h
@@ -20,7 +20,7 @@
#ifndef KROSS_KEXIDB_KEXIDBFIELD_H
#define KROSS_KEXIDB_KEXIDBFIELD_H
-#include <qstring.h>
+#include <tqstring.h>
#include <api/object.h>
#include <api/list.h>
@@ -39,27 +39,27 @@ namespace Kross { namespace KexiDB {
public:
KexiDBField(::KexiDB::Field* field);
virtual ~KexiDBField();
- virtual const QString getClassName() const;
+ virtual const TQString getClassName() const;
::KexiDB::Field* field() { return m_field; }
private:
/** Returns the type string for this field, e.g. "Integer" for Integer type. */
- const QString type();
+ const TQString type();
/** Sets the type string for this field, e.g. "Integer" for Integer type. */
- void setType(const QString type);
+ void setType(const TQString type);
/** Returns the optional subtype for this field. Subtype is a string providing
additional hint for field's type. E.g. for BLOB type, it can be a MIME type or
- certain QVariant type name, for example: "QPixmap", "QColor" or "QFont". */
- const QString subType();
+ certain TQVariant type name, for example: TQPIXMAP_OBJECT_NAME_STRING, "TQColor" or "TQFont". */
+ const TQString subType();
/** Sets the optional subtype for this field. */
- void setSubType(const QString& subtype);
+ void setSubType(const TQString& subtype);
- /** Returns the QVariant::typeName which is equivalent to the type this field has. */
- const QString variantType();
+ /** Returns the TQVariant::typeName which is equivalent to the type this field has. */
+ const TQString variantType();
/** Returns type group string for this field, e.g. "IntegerGroup" for IntegerGroup type. */
- const QString typeGroup();
+ const TQString typeGroup();
/** Returns true if the field is autoincrement (e.g. integer/numeric). */
bool isAutoInc();
@@ -102,19 +102,19 @@ namespace Kross { namespace KexiDB {
void setUnsigned(bool isunsigned);
/** Returns the name of this field. */
- const QString name();
+ const TQString name();
/** Sets the name of this field. */
- void setName(const QString& name);
+ void setName(const TQString& name);
/** Returns the caption of this field. */
- const QString caption();
+ const TQString caption();
/** Sets the caption of this field. */
- void setCaption(const QString& caption);
+ void setCaption(const TQString& caption);
/** Returns the descriptive text for this field. */
- const QString description();
+ const TQString description();
/** Set the description for this field. */
- void setDescription(const QString& desc);
+ void setDescription(const TQString& desc);
/** Returns the length of text if the field type is text. */
uint length();
@@ -134,9 +134,9 @@ namespace Kross { namespace KexiDB {
void setWidth(uint width);
/** Returns the default value this field has. */
- QVariant defaultValue();
+ TQVariant defaultValue();
/** Sets the default value this field has. */
- void setDefaultValue(const QVariant& defaultvalue);
+ void setDefaultValue(const TQVariant& defaultvalue);
private:
::KexiDB::Field* m_field;